---------
Wordpiece
---------

..
  .. image:: https://img.shields.io/pypi/v/wordpiece
      :target: https://pypi.org/project/wordpiece/
      :alt: PyPI Version

..
  .. image:: https://github.com/blester125/wordpiece/workflows/Unit%20Test/badge.svg
      :target: https://github.com/blester125/wordpiece/actions
      :alt: Actions Status

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :target: https://github.com/psf/black
    :alt: Code style: black

..
  .. image:: https://readthedocs.org/projects/wordpiece/badge/?version=latest
      :target: https://wordpiece.readthedocs.io/en/latest/?badge=latest
      :alt: Documentation Status
